From 6462cdedc20b08ff5aa402a991ec89b3255ba51d Mon Sep 17 00:00:00 2001
From: Masahiro Yamada <yamada.masahiro@socionext.com>
Date: Wed, 11 Mar 2015 15:54:46 +0900
Subject: [PATCH] ARM: UniPhier: adjust device trees for business transfer

Panasonic's System LSI products, UniPhier SoC family, have been
transferred to Socionext Inc.

Signed-off-by: Masahiro Yamada <yamada.masahiro@socionext.com>
---
 arch/arm/dts/uniphier-ph1-ld4-ref.dts   |  7 +++---
 arch/arm/dts/uniphier-ph1-ld4.dtsi      | 27 ++++++++++----------
 arch/arm/dts/uniphier-ph1-pro4-ref.dts  |  7 +++---
 arch/arm/dts/uniphier-ph1-pro4.dtsi     | 33 +++++++++++++------------
 arch/arm/dts/uniphier-ph1-sld3-ref.dts  |  7 +++---
 arch/arm/dts/uniphier-ph1-sld3.dtsi     | 27 ++++++++++----------
 arch/arm/dts/uniphier-ph1-sld8-ref.dts  |  7 +++---
 arch/arm/dts/uniphier-ph1-sld8.dtsi     | 27 ++++++++++----------
 arch/arm/dts/uniphier-ref-daughter.dtsi |  3 ++-
 drivers/i2c/i2c-uniphier-f.c            |  7 +++---
 drivers/i2c/i2c-uniphier.c              |  7 +++---
 drivers/serial/serial_uniphier.c        |  7 +++---
 drivers/usb/host/ehci-uniphier.c        |  5 ++--
 drivers/usb/host/xhci-uniphier.c        |  5 ++--
 include/fdtdec.h                        |  2 +-
 lib/fdtdec.c                            |  2 +-
 16 files changed, 97 insertions(+), 83 deletions(-)

diff --git a/arch/arm/dts/uniphier-ph1-ld4-ref.dts b/arch/arm/dts/uniphier-ph1-ld4-ref.dts
index d479be1d4d..d972c0230e 100644
--- a/arch/arm/dts/uniphier-ph1-ld4-ref.dts
+++ b/arch/arm/dts/uniphier-ph1-ld4-ref.dts
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-LD4 Reference Board
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -12,8 +13,8 @@
 /include/ "uniphier-ref-daughter.dtsi"
 
 / {
-	model = "Panasonic UniPhier PH1-LD4 Reference Board";
-	compatible = "panasonic,ph1-ld4-ref", "panasonic,ph1-ld4";
+	model = "UniPhier PH1-LD4 Reference Board";
+	compatible = "socionext,ph1-ld4-ref", "socionext,ph1-ld4";
 
 	memory {
 		device_type = "memory";
diff --git a/arch/arm/dts/uniphier-ph1-ld4.dtsi b/arch/arm/dts/uniphier-ph1-ld4.dtsi
index 8ed7bbf53c..c2008383c1 100644
--- a/arch/arm/dts/uniphier-ph1-ld4.dtsi
+++ b/arch/arm/dts/uniphier-ph1-ld4.dtsi
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-LD4 SoC
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -10,7 +11,7 @@
 /include/ "skeleton.dtsi"
 
 / {
-	compatible = "panasonic,ph1-ld4";
+	compatible = "socionext,ph1-ld4";
 
 	cpus {
 		#address-cells = <1>;
@@ -30,35 +31,35 @@
 		ranges;
 
 		uart0: serial@54006800 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006800 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		uart1: serial@54006900 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006900 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		uart2: serial@54006a00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006a00 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		uart3: serial@54006b00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006b00 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		i2c0: i2c@58400000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58400000 0x40>;
@@ -67,7 +68,7 @@
 		};
 
 		i2c1: i2c@58480000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58480000 0x40>;
@@ -76,7 +77,7 @@
 		};
 
 		i2c2: i2c@58500000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58500000 0x40>;
@@ -85,7 +86,7 @@
 		};
 
 		i2c3: i2c@58580000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58580000 0x40>;
@@ -94,19 +95,19 @@
 		};
 
 		usb0: usb@5a800100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a800100 0x100>;
 		};
 
 		usb1: usb@5a810100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a810100 0x100>;
 		};
 
 		usb2: usb@5a820100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a820100 0x100>;
 		};
diff --git a/arch/arm/dts/uniphier-ph1-pro4-ref.dts b/arch/arm/dts/uniphier-ph1-pro4-ref.dts
index 5bec92b8f3..f6d03e3e26 100644
--- a/arch/arm/dts/uniphier-ph1-pro4-ref.dts
+++ b/arch/arm/dts/uniphier-ph1-pro4-ref.dts
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-Pro4 Reference Board
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -12,8 +13,8 @@
 /include/ "uniphier-ref-daughter.dtsi"
 
 / {
-	model = "Panasonic UniPhier PH1-Pro4 Reference Board";
-	compatible = "panasonic,ph1-pro4-ref", "panasonic,ph1-pro4";
+	model = "UniPhier PH1-Pro4 Reference Board";
+	compatible = "socionext,ph1-pro4-ref", "socionext,ph1-pro4";
 
 	memory {
 		device_type = "memory";
diff --git a/arch/arm/dts/uniphier-ph1-pro4.dtsi b/arch/arm/dts/uniphier-ph1-pro4.dtsi
index 1247779ab0..8195266db3 100644
--- a/arch/arm/dts/uniphier-ph1-pro4.dtsi
+++ b/arch/arm/dts/uniphier-ph1-pro4.dtsi
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-Pro4 SoC
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -10,7 +11,7 @@
 /include/ "skeleton.dtsi"
 
 / {
-	compatible = "panasonic,ph1-pro4";
+	compatible = "socionext,ph1-pro4";
 
 	cpus {
 		#address-cells = <1>;
@@ -36,35 +37,35 @@
 		ranges;
 
 		uart0: serial@54006800 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006800 0x20>;
 			clock-frequency = <73728000>;
 		};
 
 		uart1: serial@54006900 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006900 0x20>;
 			clock-frequency = <73728000>;
 		};
 
 		uart2: serial@54006a00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006a00 0x20>;
 			clock-frequency = <73728000>;
 		};
 
 		uart3: serial@54006b00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006b00 0x20>;
 			clock-frequency = <73728000>;
 		};
 
 		i2c0: i2c@58780000 {
-			compatible = "panasonic,uniphier-fi2c";
+			compatible = "socionext,uniphier-fi2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58780000 0x80>;
@@ -73,7 +74,7 @@
 		};
 
 		i2c1: i2c@58781000 {
-			compatible = "panasonic,uniphier-fi2c";
+			compatible = "socionext,uniphier-fi2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58781000 0x80>;
@@ -82,7 +83,7 @@
 		};
 
 		i2c2: i2c@58782000 {
-			compatible = "panasonic,uniphier-fi2c";
+			compatible = "socionext,uniphier-fi2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58782000 0x80>;
@@ -91,7 +92,7 @@
 		};
 
 		i2c3: i2c@58783000 {
-			compatible = "panasonic,uniphier-fi2c";
+			compatible = "socionext,uniphier-fi2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58783000 0x80>;
@@ -102,7 +103,7 @@
 		/* i2c4 does not exist */
 
 		i2c5: i2c@58785000 {
-			compatible = "panasonic,uniphier-fi2c";
+			compatible = "socionext,uniphier-fi2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58785000 0x80>;
@@ -111,7 +112,7 @@
 		};
 
 		i2c6: i2c@58786000 {
-			compatible = "panasonic,uniphier-fi2c";
+			compatible = "socionext,uniphier-fi2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58786000 0x80>;
@@ -120,25 +121,25 @@
 		};
 
 		usb2: usb@5a800100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a800100 0x100>;
 		};
 
 		usb3: usb@5a810100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a810100 0x100>;
 		};
 
 		usb0: usb@65a00000 {
-			compatible = "panasonic,uniphier-xhci", "generic-xhci";
+			compatible = "socionext,uniphier-xhci", "generic-xhci";
 			status = "disabled";
 			reg = <0x65a00000 0x100>;
 		};
 
 		usb1: usb@65c00000 {
-			compatible = "panasonic,uniphier-xhci", "generic-xhci";
+			compatible = "socionext,uniphier-xhci", "generic-xhci";
 			status = "disabled";
 			reg = <0x65c00000 0x100>;
 		};
diff --git a/arch/arm/dts/uniphier-ph1-sld3-ref.dts b/arch/arm/dts/uniphier-ph1-sld3-ref.dts
index 8a7f90ac78..d9616f68a0 100644
--- a/arch/arm/dts/uniphier-ph1-sld3-ref.dts
+++ b/arch/arm/dts/uniphier-ph1-sld3-ref.dts
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-sLD3 Reference Board
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -12,8 +13,8 @@
 /include/ "uniphier-ref-daughter.dtsi"
 
 / {
-	model = "Panasonic UniPhier PH1-sLD3 Reference Board";
-	compatible = "panasonic,ph1-sld3-ref", "panasonic,ph1-sld3";
+	model = "UniPhier PH1-sLD3 Reference Board";
+	compatible = "socionext,ph1-sld3-ref", "socionext,ph1-sld3";
 
 	memory {
 		device_type = "memory";
diff --git a/arch/arm/dts/uniphier-ph1-sld3.dtsi b/arch/arm/dts/uniphier-ph1-sld3.dtsi
index 88322c6a8c..44b19897b3 100644
--- a/arch/arm/dts/uniphier-ph1-sld3.dtsi
+++ b/arch/arm/dts/uniphier-ph1-sld3.dtsi
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-sLD3 SoC
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -10,7 +11,7 @@
 /include/ "skeleton.dtsi"
 
 / {
-	compatible = "panasonic,ph1-sld3";
+	compatible = "socionext,ph1-sld3";
 
 	cpus {
 		#address-cells = <1>;
@@ -36,28 +37,28 @@
 		ranges;
 
 		uart0: serial@54006800 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006800 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		uart1: serial@54006900 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006900 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		uart2: serial@54006a00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006a00 0x20>;
 			clock-frequency = <36864000>;
 		};
 
 		i2c0: i2c@58400000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58400000 0x40>;
@@ -66,7 +67,7 @@
 		};
 
 		i2c1: i2c@58480000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58480000 0x40>;
@@ -75,7 +76,7 @@
 		};
 
 		i2c2: i2c@58500000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58500000 0x40>;
@@ -84,7 +85,7 @@
 		};
 
 		i2c3: i2c@58580000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58580000 0x40>;
@@ -93,25 +94,25 @@
 		};
 
 		usb0: usb@5a800100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a800100 0x100>;
 		};
 
 		usb1: usb@5a810100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a810100 0x100>;
 		};
 
 		usb2: usb@5a820100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a820100 0x100>;
 		};
 
 		usb3: usb@5a830100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a830100 0x100>;
 		};
diff --git a/arch/arm/dts/uniphier-ph1-sld8-ref.dts b/arch/arm/dts/uniphier-ph1-sld8-ref.dts
index 0cb9c47b65..69e9bfa9ba 100644
--- a/arch/arm/dts/uniphier-ph1-sld8-ref.dts
+++ b/arch/arm/dts/uniphier-ph1-sld8-ref.dts
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-sLD8 Reference Board
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -12,8 +13,8 @@
 /include/ "uniphier-ref-daughter.dtsi"
 
 / {
-	model = "Panasonic UniPhier PH1-sLD8 Reference Board";
-	compatible = "panasonic,ph1-sld8-ref", "panasonic,ph1-sld8";
+	model = "UniPhier PH1-sLD8 Reference Board";
+	compatible = "socionext,ph1-sld8-ref", "socionext,ph1-sld8";
 
 	memory {
 		device_type = "memory";
diff --git a/arch/arm/dts/uniphier-ph1-sld8.dtsi b/arch/arm/dts/uniphier-ph1-sld8.dtsi
index 1b3eb228c8..d9f61c2231 100644
--- a/arch/arm/dts/uniphier-ph1-sld8.dtsi
+++ b/arch/arm/dts/uniphier-ph1-sld8.dtsi
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier PH1-sLD8 SoC
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -10,7 +11,7 @@
 /include/ "skeleton.dtsi"
 
 / {
-	compatible = "panasonic,ph1-sld8";
+	compatible = "socionext,ph1-sld8";
 
 	cpus {
 		#address-cells = <1>;
@@ -30,35 +31,35 @@
 		ranges;
 
 		uart0: serial@54006800 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006800 0x20>;
 			clock-frequency = <80000000>;
 		};
 
 		uart1: serial@54006900 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006900 0x20>;
 			clock-frequency = <80000000>;
 		};
 
 		uart2: serial@54006a00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006a00 0x20>;
 			clock-frequency = <80000000>;
 		};
 
 		uart3: serial@54006b00 {
-			compatible = "panasonic,uniphier-uart";
+			compatible = "socionext,uniphier-uart";
 			status = "disabled";
 			reg = <0x54006b00 0x20>;
 			clock-frequency = <80000000>;
 		};
 
 		i2c0: i2c@58400000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58400000 0x40>;
@@ -67,7 +68,7 @@
 		};
 
 		i2c1: i2c@58480000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58480000 0x40>;
@@ -76,7 +77,7 @@
 		};
 
 		i2c2: i2c@58500000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58500000 0x40>;
@@ -85,7 +86,7 @@
 		};
 
 		i2c3: i2c@58580000 {
-			compatible = "panasonic,uniphier-i2c";
+			compatible = "socionext,uniphier-i2c";
 			#address-cells = <1>;
 			#size-cells = <0>;
 			reg = <0x58580000 0x40>;
@@ -94,19 +95,19 @@
 		};
 
 		usb0: usb@5a800100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a800100 0x100>;
 		};
 
 		usb1: usb@5a810100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a810100 0x100>;
 		};
 
 		usb2: usb@5a820100 {
-			compatible = "panasonic,uniphier-ehci", "generic-ehci";
+			compatible = "socionext,uniphier-ehci", "generic-ehci";
 			status = "disabled";
 			reg = <0x5a820100 0x100>;
 		};
diff --git a/arch/arm/dts/uniphier-ref-daughter.dtsi b/arch/arm/dts/uniphier-ref-daughter.dtsi
index 0145b51780..aca9f58b25 100644
--- a/arch/arm/dts/uniphier-ref-daughter.dtsi
+++ b/arch/arm/dts/uniphier-ref-daughter.dtsi
@@ -2,7 +2,8 @@
  * Device Tree Source for UniPhier Reference Daughter Board
  *
  * Copyright (C) 2014-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
diff --git a/drivers/usb/host/ehci-uniphier.c b/drivers/usb/host/ehci-uniphier.c
index b5ec296918..846bf509d6 100644
--- a/drivers/usb/host/ehci-uniphier.c
+++ b/drivers/usb/host/ehci-uniphier.c
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2014 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015 Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -16,7 +17,7 @@
 DECLARE_GLOBAL_DATA_PTR;
 
 #define FDT		gd->fdt_blob
-#define COMPAT		"panasonic,uniphier-ehci"
+#define COMPAT		"socionext,uniphier-ehci"
 
 static int get_uniphier_ehci_base(int index, struct ehci_hccr **base)
 {
diff --git a/lib/fdtdec.c b/lib/fdtdec.c
index 21933e4a47..1a0268a3f9 100644
--- a/lib/fdtdec.c
+++ b/lib/fdtdec.c
@@ -76,7 +76,7 @@ static const char * const compat_names[COMPAT_COUNT] = {
 	COMPAT(AMS_AS3722, "ams,as3722"),
 	COMPAT(INTEL_ICH_SPI, "intel,ich-spi"),
 	COMPAT(INTEL_QRK_MRC, "intel,quark-mrc"),
-	COMPAT(PANASONIC_XHCI, "panasonic,uniphier-xhci"),
+	COMPAT(SOCIONEXT_XHCI, "socionext,uniphier-xhci"),
 };
 
 const char *fdtdec_get_compatible(enum fdt_compat_id id)
diff --git a/drivers/i2c/i2c-uniphier-f.c b/drivers/i2c/i2c-uniphier-f.c
index 6707edd9ef..fd28c17399 100644
--- a/drivers/i2c/i2c-uniphier-f.c
+++ b/drivers/i2c/i2c-uniphier-f.c
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2014 Panasonic Corporation
  *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -352,8 +353,8 @@ static const struct dm_i2c_ops uniphier_fi2c_ops = {
 };
 
 static const struct udevice_id uniphier_fi2c_of_match[] = {
-	{ .compatible = "panasonic,uniphier-fi2c" },
-	{},
+	{ .compatible = "socionext,uniphier-fi2c" },
+	{ /* sentinel */ }
 };
 
 U_BOOT_DRIVER(uniphier_fi2c) = {
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2014 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015 Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
diff --git a/drivers/i2c/i2c-uniphier.c b/drivers/i2c/i2c-uniphier.c
index 64a9ed81d2..666272dd0d 100644
--- a/drivers/i2c/i2c-uniphier.c
+++ b/drivers/i2c/i2c-uniphier.c
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2014 Panasonic Corporation
  *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -212,8 +213,8 @@ static const struct dm_i2c_ops uniphier_i2c_ops = {
 };
 
 static const struct udevice_id uniphier_i2c_of_match[] = {
-	{ .compatible = "panasonic,uniphier-i2c" },
-	{},
+	{ .compatible = "socionext,uniphier-i2c" },
+	{ /* sentinel */ }
 };
 
 U_BOOT_DRIVER(uniphier_i2c) = {
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2014 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015 Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
diff --git a/drivers/serial/serial_uniphier.c b/drivers/serial/serial_uniphier.c
index a6bd27facf..98e3b812e0 100644
--- a/drivers/serial/serial_uniphier.c
+++ b/drivers/serial/serial_uniphier.c
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2012-2015 Panasonic Corporation
  *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -115,8 +116,8 @@ static int uniphier_serial_remove(struct udevice *dev)
 
 #ifdef CONFIG_OF_CONTROL
 static const struct udevice_id uniphier_uart_of_match[] = {
-	{ .compatible = "panasonic,uniphier-uart" },
-	{},
+	{ .compatible = "socionext,uniphier-uart" },
+	{ /* sentinel */ }
 };
 
 static int uniphier_serial_ofdata_to_platdata(struct udevice *dev)
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2012-2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015      Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
diff --git a/drivers/usb/host/xhci-uniphier.c b/drivers/usb/host/xhci-uniphier.c
index 08b15e0ad1..e0ef322172 100644
--- a/drivers/usb/host/xhci-uniphier.c
+++ b/drivers/usb/host/xhci-uniphier.c
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2015 Panasonic Corporation
  *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
  */
@@ -19,7 +20,7 @@ static int get_uniphier_xhci_base(int index, struct xhci_hccr **base)
 	int count;
 
 	count = fdtdec_find_aliases_for_id(gd->fdt_blob, "usb",
-					   COMPAT_PANASONIC_XHCI, node_list,
+					   COMPAT_SOCIONEXT_XHCI, node_list,
 					   ARRAY_SIZE(node_list));
 
 	if (index >= count)
@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2015 Panasonic Corporation
- *   Author: Masahiro Yamada <yamada.m@jp.panasonic.com>
+ * Copyright (C) 2015 Socionext Inc.
+ *   Author: Masahiro Yamada <yamada.masahiro@socionext.com>
  *
  * SPDX-License-Identifier:	GPL-2.0+
diff --git a/include/fdtdec.h b/include/fdtdec.h
index 1233dfb280..5ac515d87d 100644
--- a/include/fdtdec.h
+++ b/include/fdtdec.h
@@ -168,7 +168,7 @@ enum fdt_compat_id {
 	COMPAT_AMS_AS3722,		/* AMS AS3722 PMIC */
 	COMPAT_INTEL_ICH_SPI,		/* Intel ICH7/9 SPI controller */
 	COMPAT_INTEL_QRK_MRC,		/* Intel Quark MRC */
-	COMPAT_PANASONIC_XHCI,		/* Panasonic UniPhier xHCI */
+	COMPAT_SOCIONEXT_XHCI,		/* Socionext UniPhier xHCI */
 
 	COMPAT_COUNT,
 };
-- 
2.39.5